.. _uctl:

UCtl
####

.. automodule:: urgap.uctl.run
   :members:

.. automodule:: urgap.uctl.describe
   :members:


.. automodule:: urgap.uctl.info
   :members:


.. automodule:: urgap.uctl.uctl
   :members:


.. automodule:: urgap.uctl.upload
   :members:

.. automodule:: urgap.uctl.set
   :members:

.. automodule:: urgap.uctl.show
   :members:
